@@ -52,8 +52,8 @@ class ColorFormatter(logging.Formatter):
         return f"{color}{logging.Formatter.format(self, record)}{self.NC}"
 
 
-def add_logger_methods():
-    """"""
+def add_logger_methods() -> None:
+    """Patch in two methods for the Python logger."""
     logging.Logger.success = types.MethodType(success_wrap, logging.Logger)
     logging.RootLogger.success = types.MethodType(success_wrap, logging.RootLogger)
     logging.Logger.extra = types.MethodType(extra_wrap, logging.Logger)
@@ -85,7 +85,7 @@ def create_logger(name: str, level: int = logging.DEBUG, file_path: pathlib.Path
     return logger
 
 
-def set_defaults(level: int = logging.DEBUG, file_path: [pathlib.Path, str] = None):
+def set_defaults(level: int = logging.DEBUG, file_path: [pathlib.Path, str] = None) -> None:
     """Set the default logger options."""
     add_logger_methods()
 
@@ -105,7 +105,7 @@ def set_defaults(level: int = logging.DEBUG, file_path: [pathlib.Path, str] = No
             level=level,
             format="[%(asctime)s] %(levelname)s - %(message)s",
             datefmt="%H:%M:%S",
-            handlers=[console_handler],
+            # handlers=[console_handler],
         )
 
 
